@@ -2,7 +2,7 @@
 //
 // Export a Rivendell SoundExchange Report to an ASCII Text File.
 //
-//   (C) Copyright 2002-2006,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2006,2016-2017 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,9 +29,8 @@
 #include <rdreport.h>
 #include <rdget_ath.h>
 
-
-bool RDReport::ExportSoundEx(const QDate &startdate,const QDate &enddate,
-			     const QString &mixtable)
+bool RDReport::ExportSoundEx(const QString &filename,const QDate &startdate,
+			     const QDate &enddate,const QString &mixtable)
 {
   QString sql;
   RDSqlQuery *q;
@@ -47,14 +46,6 @@ bool RDReport::ExportSoundEx(const QDate &startdate,const QDate &enddate,
   QString trans_category=stationFormat();
   QString channel_name=stationId();
 
-#ifdef WIN32
-  QString filename=
-    RDDateDecode(exportPath(RDReport::Windows),startdate,serviceName());
-#else
-  QString filename=
-    RDDateDecode(exportPath(RDReport::Linux),startdate,serviceName());
-#endif
-
   //
   // Get ATH Value
   //
