@@ -2,7 +2,7 @@
 //
 // Export a Rivendell Technical Report to an ASCII Text File.
 //
-//   (C) Copyright 2002-2006,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2006,2016-2017 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,9 +29,8 @@
 #include <rddatedecode.h>
 #include <rdreport.h>
 
-
-bool RDReport::ExportTechnical(const QDate &startdate,const QDate &enddate,
-			       bool incl_hdr,bool incl_crs,
+bool RDReport::ExportTechnical(const QString &filename,const QDate &startdate,
+			       const QDate &enddate,bool incl_hdr,bool incl_crs,
 			       const QString &mixtable)
 {
   QString sql;
@@ -43,16 +42,9 @@ bool RDReport::ExportTechnical(const QDate &startdate,const QDate &enddate,
   QString cart_num;
   char eol[3]="\n";
 
-#ifdef WIN32
-  QString filename=
-    RDDateDecode(exportPath(RDReport::Windows),startdate,serviceName());
-#else
-  QString filename=
-    RDDateDecode(exportPath(RDReport::Linux),startdate,serviceName());
   if(incl_crs) {
     strcpy(eol,"\r\n");
   }
-#endif
 
   QFile file(filename);
   if((f=fopen((const char *)filename,"w"))==NULL) {
