@@ -527,6 +527,14 @@
         <source>No such service!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>No such group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No free cart available in group</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -895,10 +903,6 @@ Color</translation>
         <source>Unable to create temporary cart for import!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Unable to get temporary cart number for import!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Import Error</source>
         <translation type="unfinished">Error importando</translation>
@@ -2425,5 +2429,13 @@ please try again!</source>
         <translation>Errores al llenar eventos
 </translation>
     </message>
+    <message>
+        <source>Log in use by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Import failed</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
