@@ -2,9 +2,7 @@
 //
 // Abstract a Rivendell Cart
 //
-//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rddbheartbeat.h,v 1.2 2007/02/14 21:48:41 fredg Exp $
+//   (C) Copyright 2002-2006,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,19 +18,18 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#ifndef RDDBHEARTBEAT_H
+#define RDDBHEARTBEAT_H
+
 #include <qobject.h>
 #include <qsqldatabase.h>
 #include <qtimer.h>
 
-
-#ifndef RDDBHEARTBEAT_H
-#define RDDBHEARTBEAT_H
-
 class RDDbHeartbeat : public QObject
 {
   Q_OBJECT;
  public:
-  RDDbHeartbeat(int interval,QObject *parent=0,const char *name=0);
+  RDDbHeartbeat(int interval,QObject *parent=0);
 
  private slots:
   void intervalTimeoutData();
