@@ -1,10 +1,8 @@
 // import_audio.h
 //
-// CD Ripper Dialog for Rivendell
+// Audio File Importation Dialog for Rivendell.
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdimport_audio.h,v 1.8.2.1 2010/02/09 21:43:53 cvs Exp $
+//   (C) Copyright 2002-2015 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -39,16 +37,15 @@
 #include <qbuttongroup.h>
 #include <qradiobutton.h>
 
+#include <rdbusybar.h>
 #include <rdwavedata.h>
 #include <rdconfig.h>
 #include <rdsettings.h>
 #include <rdexport_settings_dialog.h>
 #include <rdcut.h>
-
-//
-// Global Variables
-//
-extern bool ripper_running;
+#include <rduser.h>
+#include <rdaudioexport.h>
+#include <rdaudioimport.h>
 
 //
 // Widget Settings
@@ -63,8 +60,8 @@ class RDImportAudio : public QDialog
  public:
  RDImportAudio(QString cutname,QString *path,RDSettings *settings,
 	       bool *import_metadata,RDWaveData *wavedata,
-	       RDCut *clipboard,RDStation *station,bool *running,
-	       RDConfig *config,QWidget *parent=0,const char *name=0);
+	       RDCut *clipboard,RDStation *station,RDUser *user,bool *running,
+	       RDConfig *config,QWidget *parent=0);
   ~RDImportAudio();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
@@ -82,7 +79,6 @@ class RDImportAudio : public QDialog
   void filenameChangedData(const QString &str);
   void normalizeCheckData(bool state);
   void autotrimCheckData(bool state);
-  void barTimerData();
   void selectInputFileData();
   void selectOutputFileData();
   void selectOutputFormatData();
@@ -95,14 +91,13 @@ class RDImportAudio : public QDialog
 
  private:
   void Import();
-  void ImportProgress();
   void Export();
-  void ExportProgress();
-  void AutoTrim();
-  unsigned GetFileSize(const QString &filename);
+  void StartBar();
+  void StopBar();
   RDConfig *import_config;
   RDSettings *import_default_settings;
   RDStation *import_station;
+  RDUser *import_user;
   RDCut *import_clipboard;
   bool *import_running;
   QButtonGroup *import_mode_group;
@@ -120,8 +115,7 @@ class RDImportAudio : public QDialog
   QLabel *import_format_label;
   QLineEdit *import_format_edit;
   QPushButton *import_out_format_button;
-  QProgressBar *import_bar;
-  QTimer *import_bar_timer;
+  RDBusyBar *import_bar;
   QCheckBox *import_normalize_box;
   QSpinBox *import_normalize_spin;
   QLabel *import_normalize_label;
@@ -135,21 +129,15 @@ class RDImportAudio : public QDialog
   QPushButton *import_import_button;
   QString *import_path;
   QString import_file_filter;
-  bool import_multipass;
   QString import_cutname;
   QString import_dest_filename;
-  QFile bar_temp_file;
-  pid_t import_script_pid;
   bool import_import_aborted;
-  unsigned import_temp_length;
-  unsigned import_finished_length;
   bool *import_import_metadata;
   RDSettings *import_settings;
   RDWaveData *import_wavedata;
-  QString import_tempwav_name;
-  QString import_tempdat_name;
+  RDAudioImport *import_import_conv;
+  RDAudioExport *import_export_conv;
 };
 
 
-#endif
-
+#endif  // RDIMPORT_AUDIO_H
