@@ -26,6 +26,11 @@
 #include <qobject.h>
 #include <qsqldatabase.h>
 
+#include "rdconfig.h"
+#include "rdloglock.h"
+#include "rdstation.h"
+#include "rduser.h"
+
 class RDSvc : public QObject
 {
   Q_OBJECT
@@ -35,7 +40,8 @@ class RDSvc : public QObject
   enum ImportField {CartNumber=0,ExtData=3,ExtEventId=4,ExtAnncType=5,
 		    Title=6,StartHours=7,StartMinutes=8,StartSeconds=9,
 		    LengthHours=10,LengthMinutes=11,LengthSeconds=12};
-  RDSvc(QString svcname,QObject *parent=0);
+  enum ShelflifeOrigin {OriginAirDate=0,OriginCreationDate=1};
+  RDSvc(QString svcname,RDStation *station,RDConfig *config,QObject *parent=0);
   QString name() const;
   bool exists() const;
   QString description() const;
@@ -54,6 +60,8 @@ class RDSvc : public QObject
   void setAutoRefresh(bool state);
   int defaultLogShelflife() const;
   void setDefaultLogShelflife(int days) const;
+  ShelflifeOrigin logShelflifeOrigin() const;
+  void setLogShelflifeOrigin(ShelflifeOrigin orig);
   int elrShelflife() const;
   void setElrShelflife(int days) const;
   bool chainto() const;
@@ -82,17 +90,20 @@ class RDSvc : public QObject
 	      const QString &track_str,const QString &dest_table) 
     const;
   bool generateLog(const QDate &date,const QString &logname,
-		   const QString &nextname,QString *report);
+		   const QString &nextname,QString *report,RDUser *user,
+		   QString *err_msg);
   bool linkLog(RDSvc::ImportSource src,const QDate &date,
-	       const QString &logname,QString *report);
-  void clearLogLinks(RDSvc::ImportSource src,const QDate &date,
-		     const QString &logname);
+	       const QString &logname,QString *report,RDUser *user,
+	       QString *err_msg);
+  bool clearLogLinks(RDSvc::ImportSource src,const QString &logname,
+		     RDUser *user,QString *err_msg);
   void create(const QString exemplar) const;
   void remove() const;
   QString xml() const;
   static bool create(const QString &name,QString *err_msg,
-		     const QString &exemplar);
+		     const QString &exemplar,RDConfig *config);
   static void remove(const QString &name);
+  static bool exists(const QString &name);
   static QString timeString(int hour,int secs);
   static QString svcTableName(const QString &svc_name);
 
@@ -100,6 +111,7 @@ class RDSvc : public QObject
   void generationProgress(int step);
 
  private:
+  bool TryLock(RDLogLock *lock,QString *err_msg);
   QString SourceString(ImportSource src) const;
   QString OsString(ImportOs os) const;
   QString FieldString(ImportField field) const;
@@ -109,6 +121,8 @@ class RDSvc : public QObject
 			QString *label_cart,QString *track_cart);
   bool CheckId(std::vector<int> *v,int value);
   QString svc_name;
+  RDStation *svc_station;
+  RDConfig *svc_config;
 };
 
 
