@@ -2,9 +2,7 @@
 //
 // Edit a Rivendell Group
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_group.cpp,v 1.27.8.1 2013/01/07 13:50:22 cvs Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -40,9 +38,8 @@
 #include <rdpasswd.h>
 #include <rdtextvalidator.h>
 
-
-EditGroup::EditGroup(QString group,QWidget *parent,const char *name)
-  : QDialog(parent,name,true)
+EditGroup::EditGroup(QString group,QWidget *parent)
+  : QDialog(parent,"",true)
 {
   QString sql;
   RDSqlQuery *q;
@@ -68,83 +65,65 @@ EditGroup::EditGroup(QString group,QWidget *parent,const char *name)
   //
   // Text Validator
   //
-  RDTextValidator *validator=new RDTextValidator(this,"validator");
+  RDTextValidator *validator=new RDTextValidator(this);
 
   //
   // Group Name
   //
-  group_name_edit=new QLineEdit(this,"group_name_edit");
-  group_name_edit->setGeometry(165,11,100,19);
+  group_name_edit=new QLineEdit(this);
   group_name_edit->setMaxLength(10);
   group_name_edit->setReadOnly(true);
-  QLabel *group_name_label=new QLabel(group_name_edit,tr("&Group Name:"),this,
-				       "group_name_label");
-  group_name_label->setGeometry(10,11,150,19);
+  group_name_label=new QLabel(group_name_edit,tr("&Group Name:"),this);
   group_name_label->setFont(font);
   group_name_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
   //
   // Group Description
   //
-  group_description_edit=new QLineEdit(this,"group_description_edit");
-  group_description_edit->setGeometry(165,32,sizeHint().width()-175,19);
+  group_description_edit=new QLineEdit(this);
   group_description_edit->setMaxLength(255);
   group_description_edit->setValidator(validator);
-  QLabel *group_description_label=new QLabel(group_description_edit,
-					     tr("Group &Description:"),this,
-					     "group_description_label");
-  group_description_label->setGeometry(10,32,150,19);
+  group_description_label=
+    new QLabel(group_description_edit,tr("Group &Description:"),this);
   group_description_label->setFont(font);
   group_description_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
   //
   // Default Title
   //
-  group_title_edit=new QLineEdit(this,"group_title_edit");
-  group_title_edit->setGeometry(165,53,sizeHint().width()-175,19);
+  group_title_edit=new QLineEdit(this);
   group_title_edit->setMaxLength(255);
   group_title_edit->setValidator(validator);
-  QLabel *group_title_label=new QLabel(group_title_edit,
-					     tr("Default Import &Title:"),this,
-					     "group_title_label");
-  group_title_label->setGeometry(10,53,150,19);
+  group_title_label=
+    new QLabel(group_title_edit,tr("Default Import &Title:"),this);
   group_title_label->setFont(font);
   group_title_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
   //
   // Default Cart Type
   //
-  group_carttype_box=new QComboBox(this,"group_carttype_box");
-  group_carttype_box->setGeometry(165,74,100,19);
+  group_carttype_box=new QComboBox(this);
   group_carttype_box->insertItem(tr("Audio"));
   group_carttype_box->insertItem(tr("Macro"));
-  QLabel *group_carttype_label=new QLabel(group_carttype_box,
-					     tr("Default Cart &Type:"),this,
-					     "group_carttype_label");
-  group_carttype_label->setGeometry(10,74,150,19);
+  group_carttype_label=
+    new QLabel(group_carttype_box,tr("Default Cart &Type:"),this);
   group_carttype_label->setFont(font);
   group_carttype_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
   //
   // Default Cart Numbers
   //
-  group_lowcart_box=new QSpinBox(this,"group_lowcart_box");
-  group_lowcart_box->setGeometry(165,95,70,19);
+  group_lowcart_box=new QSpinBox(this);
   group_lowcart_box->setRange(0,999999);
   group_lowcart_box->setSpecialValueText(tr("None"));
-  QLabel *label=new QLabel(group_lowcart_box,
-			   tr("Default Cart Number:"),this,
-			   "group_lowcart_label");
-  label->setGeometry(10,95,150,19);
-  label->setFont(font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
-  group_highcart_box=new QSpinBox(this,"group_highcart_box");
-  group_highcart_box->setGeometry(265,95,70,19);
+  group_cartrange_label=
+    new QLabel(group_lowcart_box,tr("Default Cart Number:"),this);
+  group_cartrange_label->setFont(font);
+  group_cartrange_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  group_highcart_box=new QSpinBox(this);
   group_highcart_box->setRange(1,999999);
-  group_highcart_label=new QLabel(group_highcart_box,
-				  tr("to"),this,
-				  "group_highcart_label");
-  group_highcart_label->setGeometry(240,95,20,19);
+  group_highcart_label=
+    new QLabel(group_highcart_box,tr("to"),this);
   group_highcart_label->setFont(font);
   group_highcart_label->setAlignment(AlignCenter|ShowPrefix);
   connect(group_lowcart_box,SIGNAL(valueChanged(int)),
@@ -153,90 +132,89 @@ EditGroup::EditGroup(QString group,QWidget *parent,const char *name)
   //
   // Enforce Cart Range Checkbox
   //
-  group_enforcerange_box=new QCheckBox(this,"group_enforcerange_box");
-  group_enforcerange_box->setGeometry(20,118,15,15);
+  group_enforcerange_box=new QCheckBox(this);
   group_enforcerange_label=
-    new QLabel(group_enforcerange_box,tr("Enforce Cart Range"),
-	       this,"group_enforcerange_label");
-  group_enforcerange_label->setGeometry(40,118,sizeHint().width()-50,19);
+    new QLabel(group_enforcerange_box,tr("Enforce Cart Range"),this);
   group_enforcerange_label->setFont(font);
   group_enforcerange_label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
   //
   // Traffic Report Checkbox
   //
-  group_traffic_check=new QCheckBox(this,"group_traffic_check");
-  group_traffic_check->setGeometry(20,145,15,15);
-  label=
+  group_traffic_check=new QCheckBox(this);
+  group_traffic_label=
     new QLabel(group_traffic_check,tr("Include this group in Traffic reports"),
-	       this,"group_traffic_label");
-  label->setGeometry(40,143,sizeHint().width()-50,19);
-  label->setFont(font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+	       this);
+  group_traffic_label->setFont(font);
+  group_traffic_label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
   //
   // Music Report Checkbox
   //
-  group_music_check=new QCheckBox(this,"group_music_check");
-  group_music_check->setGeometry(20,166,15,15);
-  label=new QLabel(group_music_check,tr("Include this group in Music reports"),
-		   this,"group_music_label");
-  label->setGeometry(40,164,sizeHint().width()-50,19);
-  label->setFont(font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  group_music_check=new QCheckBox(this);
+  group_music_label=new QLabel(group_music_check,tr("Include this group in Music reports"),
+		   this);
+  group_music_label->setFont(font);
+  group_music_label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+
+  //
+  // Default Cut End DateTime
+  //
+  group_cutlife_check=new QCheckBox(this);
+  connect(group_cutlife_check,SIGNAL(toggled(bool)),
+	  this,SLOT(cutLifeEnabledData(bool)));
+  group_cutlife_spin=new QSpinBox(this);
+  group_cutlife_spin->setRange(0,999);
+  group_cutlife_label=
+    new QLabel(group_cutlife_check,tr("Set End Date/Time to"),this);
+  group_cutlife_label->setFont(font);
+  group_cutlife_label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  group_cutlife_unit=
+    new QLabel(group_cutlife_check,tr("days after cut creation"),this);
+  group_cutlife_unit->setFont(font);
+  group_cutlife_unit->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
   //
   // Cut Auto Purging
   //
-  group_shelflife_check=new QCheckBox(this,"group_shelflife_check");
-  group_shelflife_check->setGeometry(20,193,15,15);
+  group_shelflife_check=new QCheckBox(this);
   connect(group_shelflife_check,SIGNAL(toggled(bool)),
 	  this,SLOT(purgeEnabledData(bool)));
-  group_shelflife_spin=new QSpinBox(this,"group_shelflife_spin");
-  group_shelflife_spin->setGeometry(200,191,40,19);
+  group_shelflife_spin=new QSpinBox(this);
   group_shelflife_spin->setRange(0,30);
   group_shelflife_label=
-    new QLabel(group_shelflife_check,tr("Purge expired cuts after"),
-	       this,"group_shelflife_label");
-  group_shelflife_label->setGeometry(40,193,160,19);
+    new QLabel(group_shelflife_check,tr("Purge expired cuts after"),this);
   group_shelflife_label->setFont(font);
   group_shelflife_label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
   group_shelflife_unit=
-    new QLabel(group_shelflife_check,tr("days"),this,"group_shelflife_unit");
-  group_shelflife_unit->setGeometry(250,193,50,19);
+    new QLabel(group_shelflife_check,tr("days"),this);
   group_shelflife_unit->setFont(font);
   group_shelflife_unit->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
   group_delete_carts_check=new QCheckBox(this);
-  group_delete_carts_check->setGeometry(40,214,15,15);
   group_delete_carts_label=
     new QLabel(group_delete_carts_check,tr("Delete cart if empty"),this);
-  group_delete_carts_label->setGeometry(60,214,160,19);
   group_delete_carts_label->setFont(font);
   group_delete_carts_label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
   //
   // Now & Next Data Checkbox
   //
-  group_nownext_check=new QCheckBox(this,"group_nownext_check");
-  group_nownext_check->setGeometry(20,242,15,15);
-  label=new QLabel(group_nownext_check,tr("Transmit Now && Next data"),
-		   this,"group_nownext_label");
-  label->setGeometry(40,241,sizeHint().width()-50,19);
-  label->setFont(font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  group_nownext_check=new QCheckBox(this);
+  group_nownext_label=
+    new QLabel(group_nownext_check,tr("Transmit Now && Next data"),this);
+  group_nownext_label->setFont(font);
+  group_nownext_label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
   //
   // Services Selector
   //
-  group_svcs_sel=new RDListSelector(this,"group_svcs_sel");
-  group_svcs_sel->setGeometry(10,261,380,130);
+  group_svcs_sel=new RDListSelector(this);
 
   //
   //  Color Button
   //
-  group_color_button=new QPushButton(this,"group_colorbutton");
-  group_color_button->setGeometry(10,sizeHint().height()-60,80,50);
+  group_color_button=new QPushButton(this);
   group_color_button->setFont(font);
   group_color_button->setText(tr("C&olor"));
   connect(group_color_button,SIGNAL(clicked()),this,SLOT(colorData()));
@@ -244,22 +222,19 @@ EditGroup::EditGroup(QString group,QWidget *parent,const char *name)
   //
   //  Ok Button
   //
-  QPushButton *ok_button=new QPushButton(this,"ok_button");
-  ok_button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
-  ok_button->setDefault(true);
-  ok_button->setFont(font);
-  ok_button->setText(tr("&OK"));
-  connect(ok_button,SIGNAL(clicked()),this,SLOT(okData()));
+  group_ok_button=new QPushButton(this);
+  group_ok_button->setDefault(true);
+  group_ok_button->setFont(font);
+  group_ok_button->setText(tr("&OK"));
+  connect(group_ok_button,SIGNAL(clicked()),this,SLOT(okData()));
 
   //
   //  Cancel Button
   //
-  QPushButton *cancel_button=new QPushButton(this,"cancel_button");
-  cancel_button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,
-			     80,50);
-  cancel_button->setFont(font);
-  cancel_button->setText(tr("&Cancel"));
-  connect(cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
+  group_cancel_button=new QPushButton(this);
+  group_cancel_button->setFont(font);
+  group_cancel_button->setText(tr("&Cancel"));
+  connect(group_cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
   //
   // Populate Fields
@@ -274,6 +249,11 @@ EditGroup::EditGroup(QString group,QWidget *parent,const char *name)
   group_enforcerange_box->setChecked(group_group->enforceCartRange());
   group_traffic_check->setChecked(group_group->exportReport(RDGroup::Traffic));
   group_music_check->setChecked(group_group->exportReport(RDGroup::Music));
+  if(group_group->defaultCutLife()>=0) {
+    group_cutlife_spin->setValue(group_group->defaultCutLife());
+    group_cutlife_check->setChecked(true);
+  }
+  cutLifeEnabledData(group_cutlife_check->isChecked());
   if(group_group->cutShelflife()>=0) {
     group_shelflife_spin->setValue(group_group->cutShelflife());
     group_shelflife_check->setChecked(true);
@@ -312,7 +292,7 @@ EditGroup::~EditGroup()
 
 QSize EditGroup::sizeHint() const
 {
-  return QSize(400,472);
+  return QSize(400,493);
 } 
 
 
@@ -343,16 +323,22 @@ void EditGroup::lowCartChangedData(int value)
 
 void EditGroup::colorData()
 {
-  QColor color=QColorDialog::getColor(group_color_button->
-				      palette().color(QPalette::Active,
-						      QColorGroup::ButtonText),
-				      this,"color_dialog");
+  QColor color=
+    QColorDialog::getColor(group_color_button->palette().color(QPalette::Active,
+			   QColorGroup::ButtonText),this);
   if(color.isValid()) {
     SetButtonColor(color);
   }
 }
 
 
+void EditGroup::cutLifeEnabledData(bool state)
+{
+  group_cutlife_spin->setEnabled(state);
+  group_cutlife_unit->setEnabled(state);
+}
+
+
 void EditGroup::purgeEnabledData(bool state)
 {
   group_shelflife_spin->setEnabled(state);
@@ -386,6 +372,12 @@ void EditGroup::okData()
   group_group->
     setExportReport(RDGroup::Traffic,group_traffic_check->isChecked());
   group_group->setExportReport(RDGroup::Music,group_music_check->isChecked());
+  if(group_cutlife_check->isChecked()) {
+    group_group->setDefaultCutLife(group_cutlife_spin->value());
+  }
+  else {
+    group_group->setDefaultCutLife(-1);
+  }
   if(group_shelflife_check->isChecked()) {
     group_group->setCutShelflife(group_shelflife_spin->value());
     group_group->setDeleteEmptyCarts(group_delete_carts_check->isChecked());
@@ -441,6 +433,59 @@ void EditGroup::cancelData()
 }
 
 
+void EditGroup::resizeEvent(QResizeEvent *e)
+{
+  group_name_edit->setGeometry(165,11,100,19);
+  group_name_label->setGeometry(10,11,150,19);
+
+  group_description_edit->setGeometry(165,32,size().width()-175,19);
+  group_description_label->setGeometry(10,32,150,19);
+
+  group_title_edit->setGeometry(165,53,size().width()-175,19);
+  group_title_label->setGeometry(10,53,150,19);
+
+  group_carttype_box->setGeometry(165,74,100,19);
+  group_carttype_label->setGeometry(10,74,150,19);
+
+  group_lowcart_box->setGeometry(165,95,70,19);
+  group_cartrange_label->setGeometry(10,95,150,19);
+  group_highcart_box->setGeometry(265,95,70,19);
+  group_highcart_label->setGeometry(240,95,20,19);
+
+  group_enforcerange_box->setGeometry(20,118,15,15);
+  group_enforcerange_label->setGeometry(40,118,size().width()-50,19);
+
+  group_traffic_check->setGeometry(20,145,15,15);
+  group_traffic_label->setGeometry(40,143,size().width()-50,19);
+
+  group_music_check->setGeometry(20,166,15,15);
+  group_music_label->setGeometry(40,164,size().width()-50,19);
+
+  group_cutlife_check->setGeometry(20,193,15,15);
+  group_cutlife_label->setGeometry(40,193,140,19);
+  group_cutlife_spin->setGeometry(185,191,45,19);
+  group_cutlife_unit->setGeometry(245,193,size().width()-245,19);
+
+  group_shelflife_check->setGeometry(20,214,15,15);
+  group_shelflife_spin->setGeometry(200,212,40,19);
+  group_shelflife_label->setGeometry(40,214,160,19);
+  group_shelflife_unit->setGeometry(250,214,50,19);
+
+  group_delete_carts_check->setGeometry(40,235,15,15);
+  group_delete_carts_label->setGeometry(60,235,160,19);
+
+  group_nownext_check->setGeometry(20,263,15,15);
+  group_nownext_label->setGeometry(40,262,size().width()-50,19);
+
+  group_svcs_sel->setGeometry(10,285,401,130);
+
+  group_color_button->setGeometry(10,size().height()-60,80,50);
+
+  group_ok_button->setGeometry(size().width()-180,size().height()-60,80,50);
+  group_cancel_button->setGeometry(size().width()-90,size().height()-60,80,50);
+}
+
+
 bool EditGroup::CheckRange()
 {
   if(group_lowcart_box->value()==0) {
