@@ -2,9 +2,7 @@
 //
 // List Rivendell Reports
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: list_reports.h,v 1.7 2010/07/29 19:32:35 cvs Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,12 +28,11 @@
 #include <qradiobutton.h>
 #include <qsqldatabase.h>
 
-
 class ListReports : public QDialog
 {
   Q_OBJECT
   public:
-   ListReports(QWidget *parent=0,const char *name=0);
+   ListReports(QWidget *parent=0);
    ~ListReports();
    QSize sizeHint() const;
    QSizePolicy sizePolicy() const;
