@@ -22,15 +22,17 @@
 #include <qpainter.h>
 #include <qmessagebox.h>
 
-#include <rddatedialog.h>
-#include <rdconf.h>
-#include <rddb.h>
-#include <test_import.h>
-#include <rduser.h>
-#include <rdpasswd.h>
-#include <rddatedecode.h>
-#include <rdlistviewitem.h>
-#include <rdevent_line.h>
+#include "globals.h"
+#include "rdconf.h"
+#include "rddatedecode.h"
+#include "rddatedialog.h"
+#include "rddb.h"
+#include "rdevent_line.h"
+#include "rdlistviewitem.h"
+#include "rdpasswd.h"
+#include "rduser.h"
+
+#include "test_import.h"
 
 TestImport::TestImport(RDSvc *svc,RDSvc::ImportSource src,QWidget *parent)
   : QDialog(parent,"",true)
@@ -116,7 +118,7 @@ TestImport::TestImport(RDSvc *svc,RDSvc::ImportSource src,QWidget *parent)
   test_events_list->setColumnAlignment(2,AlignRight);
   test_events_list->addColumn(tr("Title"));
   test_events_list->setColumnAlignment(3,AlignLeft);
-  test_events_list->addColumn(tr("Contract #"));
+  test_events_list->addColumn(tr("GUID"));
   test_events_list->setColumnAlignment(4,AlignCenter);
   test_events_list->addColumn(tr("Event ID"));
   test_events_list->setColumnAlignment(5,AlignCenter);
@@ -253,7 +255,8 @@ void TestImport::importData()
 void TestImport::dateChangedData(const QDate &date)
 {
   test_filename_edit->
-    setText(RDDateDecode(test_svc->importPath(test_src,RDSvc::Linux),date));
+    setText(RDDateDecode(test_svc->importPath(test_src,RDSvc::Linux),date,
+			 admin_station,admin_config,test_svc->name()));
 }
 
 
