@@ -2,9 +2,7 @@
 //
 // Display Audio Adapter Information
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: view_adapters.cpp,v 1.14 2010/07/29 19:32:35 cvs Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,9 +28,8 @@
 #include <view_adapters.h>
 
 
-ViewAdapters::ViewAdapters(RDStation *rdstation,
-			   QWidget *parent,const char *name)
-  : QDialog(parent,name,true)
+ViewAdapters::ViewAdapters(RDStation *rdstation,QWidget *parent)
+  : QDialog(parent,"",true)
 {
   QString str1;
   QString str2;
@@ -98,10 +95,14 @@ ViewAdapters::ViewAdapters(RDStation *rdstation,
       text+=tr("    MPEG Layer 2\n");
       text+=tr("    MPEG Layer 3\n");
     }
+    if(rdstation->haveCapability(RDStation::HaveMp4Decode)) {
+      text+=tr("    MP-4/AAC\n");
+    }
     if(rdstation->haveCapability(RDStation::HaveOgg123)) {
       text+=tr("    OggVorbis\n");
     }
     text+=tr("    PCM16 Linear\n");
+    text+=tr("    PCM24 Linear\n");
     text+="\n";
     text+=tr("SUPPORTED EXPORT FORMATS\n");
     if(rdstation->haveCapability(RDStation::HaveFlac)) {
@@ -117,6 +118,7 @@ ViewAdapters::ViewAdapters(RDStation *rdstation,
       text+=tr("    OggVorbis\n");
     }
     text+=tr("    PCM16 Linear\n");
+    text+=tr("    PCM24 Linear\n");
     RDEncoderList *encoders=new RDEncoderList(rdstation->name());
     for(unsigned i=0;i<encoders->encoderQuantity();i++) {
       text+="    "+encoders->encoder(i)->name()+" [Custom]\n";
