@@ -969,7 +969,7 @@ como Nuevo</translation>
     <name>MainWidget</name>
     <message>
         <source>RDCatch - Host:</source>
-        <translation>RDCatch - Computador:</translation>
+        <translation type="obsolete">RDCatch - Computador:</translation>
     </message>
     <message>
         <source>Can&apos;t Connect</source>
@@ -1255,5 +1255,25 @@ como Nuevo</translation>
         <source>Unknown</source>
         <translation>Desconocido</translation>
     </message>
+    <message>
+        <source>Host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PCM24</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Event Type</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Types</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
