@@ -43,7 +43,7 @@
     </message>
     <message>
         <source>ORIGIN</source>
-        <translation>ORIGEM</translation>
+        <translation type="obsolete">ORIGEM</translation>
     </message>
     <message>
         <source>OUTCUE</source>
@@ -228,6 +228,18 @@ Do you still want to delete?</source>
         <source>not available</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>INGEST</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SOURCE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CdRipper</name>
@@ -618,10 +630,6 @@ Disk</source>
         <source>Unable to create temporary directory!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Cut</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Track</source>
         <translation type="unfinished"></translation>
