@@ -229,11 +229,6 @@ Meta</source>
         <source>&amp;Save</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Save
-&amp;As</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Reports</source>
         <translation type="unfinished"></translation>
@@ -270,14 +265,6 @@ Do you still want to save?</source>
         <source>Add Log</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Log Exists</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Log Already Exists!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>RDLogEdit</source>
         <translation type="unfinished"></translation>
@@ -400,6 +387,30 @@ for the selected service!</source>
         <source>Len</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>As</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Render</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log Locked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log already being edited by</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditLogLine</name>
@@ -624,33 +635,6 @@ group for the specified service!</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>ListLogs</name>
-    <message>
-        <source>Select a Log</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>NAME</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>DESCRIPTION</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>SERVICE</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>ListReports</name>
     <message>
@@ -786,14 +770,6 @@ Report</source>
         <source>Add Log</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Log Exists</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Log Already Exists!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Delete Log</source>
         <translation type="unfinished"></translation>
@@ -802,11 +778,6 @@ Report</source>
         <source>This will also delete the</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>voice tracks associated with this log.
-Continue?</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Tracks Exist</source>
         <translation type="unfinished"></translation>
@@ -819,14 +790,6 @@ Continue?</source>
         <source>TFN</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>RDLogEdit</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Unable to delete log, audio deletion error!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>RDLogEdit -- Database Skew</source>
         <translation type="unfinished"></translation>
@@ -845,23 +808,150 @@ See your system administrator for an update!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Service</source>
+        <source>Are you sure you want to delete the</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ALL</source>
+        <source>log?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Filter</source>
+        <source>voice tracks associated with this log.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Clear</source>
+        <source>Continue?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Show Only Recent Logs</source>
+        <source>Are you sure you want to delete these</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>logs?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>voice tracks associated with these logs.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to delete log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>audio deletion error!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Windows</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is in use by</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RenderDialog</name>
+    <message>
+        <source>Render Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rendering Log...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Render Progress</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart/Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Render To</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio Parameters</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[now]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>As Specified</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Virtual Start Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Events</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Only Selected Events</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Include</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Stop Rendering</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Treat as PLAY</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>At STOP transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Render</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Filename</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rendering Error</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1092,5 +1182,13 @@ therefore only existing transitions will be editable.</source>
         <source>LABEL</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Log Locked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log already being edited by</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
