@@ -238,7 +238,7 @@ meta</translation>
     <message>
         <source>Save
 &amp;As</source>
-        <translation>Lagra &amp;som</translation>
+        <translation type="obsolete">Lagra &amp;som</translation>
     </message>
     <message>
         <source>&amp;Reports</source>
@@ -282,11 +282,11 @@ Vil du lagra likevel?</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation>Loggen eksisterer</translation>
+        <translation type="obsolete">Loggen eksisterer</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation>Loggen finst frå før!</translation>
+        <translation type="obsolete">Loggen finst frå før!</translation>
     </message>
     <message>
         <source>RDLogEdit</source>
@@ -408,6 +408,42 @@ skrudd av for denne tenesta!</translation>
         <source>EXT DATA</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Link Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Len</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>As</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Render</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User</source>
+        <translation type="obsolete">Brukar</translation>
+    </message>
+    <message>
+        <source>Log Locked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log already being edited by</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditLogLine</name>
@@ -653,27 +689,27 @@ som er skrudd av for denne tenesta!</translation>
     <name>ListLogs</name>
     <message>
         <source>Select a Log</source>
-        <translation>Vel ein logg</translation>
+        <translation type="obsolete">Vel ein logg</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation>NAMN</translation>
+        <translation type="obsolete">NAMN</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>SKILDRING</translation>
+        <translation type="obsolete">SKILDRING</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>TENEST</translation>
+        <translation type="obsolete">TENEST</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Avbryt</translation>
+        <translation type="obsolete">&amp;Avbryt</translation>
     </message>
 </context>
 <context>
@@ -823,11 +859,11 @@ rapport</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation>Loggen eksisterer</translation>
+        <translation type="obsolete">Loggen eksisterer</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation>Loggen finst frå før!</translation>
+        <translation type="obsolete">Loggen finst frå før!</translation>
     </message>
     <message>
         <source>Delete Log</source>
@@ -840,7 +876,7 @@ rapport</translation>
     <message>
         <source>voice tracks associated with this log.
 Continue?</source>
-        <translation>røystspor som er kopla til denne loggen.
+        <translation type="obsolete">røystspor som er kopla til denne loggen.
 Vil du halda fram?</translation>
     </message>
     <message>
@@ -857,11 +893,7 @@ Vil du halda fram?</translation>
     </message>
     <message>
         <source>RDLogEdit</source>
-        <translation type="unfinished">RDLogEdit</translation>
-    </message>
-    <message>
-        <source>Unable to delete log, audio deletion error!</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">RDLogEdit</translation>
     </message>
     <message>
         <source>RDLogEdit -- Database Skew</source>
@@ -881,19 +913,150 @@ See your system administrator for an update!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Service</source>
+        <source>Are you sure you want to delete the</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ALL</source>
+        <source>log?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Filter</source>
+        <source>voice tracks associated with this log.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Clear</source>
+        <source>Continue?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete these</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>logs?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>voice tracks associated with these logs.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to delete log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>audio deletion error!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Windows</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is in use by</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RenderDialog</name>
+    <message>
+        <source>Render Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rendering Log...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Render Progress</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart/Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Render To</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select</source>
+        <translation type="unfinished">Vel</translation>
+    </message>
+    <message>
+        <source>Audio Parameters</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[now]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>As Specified</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Virtual Start Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Events</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Only Selected Events</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Include</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Stop Rendering</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Treat as PLAY</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>At STOP transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Render</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished">&amp;Avbryt</translation>
+    </message>
+    <message>
+        <source>Filename</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rendering Error</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1124,5 +1287,13 @@ therefore only existing transitions will be editable.</source>
         <source>LABEL</source>
         <translation type="unfinished">SELSKAP</translation>
     </message>
+    <message>
+        <source>Log Locked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log already being edited by</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
