@@ -2,9 +2,7 @@
 //
 // A Utility to Purge Expired Podcasts.
 //
-//   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdpurgecasts.h,v 1.3 2010/07/29 19:32:40 cvs Exp $
+//   (C) Copyright 2002-2007,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,7 +18,6 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-
 #ifndef RDPURGECASTS_H
 #define RDPURGECASTS_H
 
@@ -32,11 +29,10 @@
 
 #define RDPURGECASTS_USAGE "[--help] [--verbose]\n\nPurge expired podcasts.\n"
 
-
 class MainObject : public QObject
 {
  public:
-  MainObject(QObject *parent=0,const char *name=0);
+  MainObject(QObject *parent=0);
 
  private:
   void PurgeCast(unsigned id);
